"use client";

import { useEffect } from "react";
import { useRouter } from "next/navigation";

export default function AuthorizePage() {
  const router = useRouter();

  useEffect(() => {
    // 检查是否有待处理的 OAuth 请求
    const pendingOAuth = localStorage.getItem("oauth_pending");
    if (pendingOAuth) {
      try {
        const params = JSON.parse(pendingOAuth);
        // 清除存储的 OAuth 参数
        localStorage.removeItem("oauth_pending");
        // 重定向到 OAuth 授权页面
        const searchParams = new URLSearchParams(params);
        router.push(`/oauth/authorize?${searchParams.toString()}`);
      } catch (error) {
        console.error("Failed to process OAuth params:", error);
        router.push("/dashboard");
      }
    } else {
      // 如果没有待处理的 OAuth 请求，直接进入仪表板
      router.push("/dashboard");
    }
  }, [router]);

  return (
    <div className="flex min-h-screen items-center justify-center">
      <div className="text-center">
        <div className="mb-4 h-8 w-8 animate-spin rounded-full border-4 border-primary border-t-transparent"></div>
        <p className="text-sm text-muted-foreground">正在处理...</p>
      </div>
    </div>
  );
}
